%define anolis_release 1
%bcond_with libdeflate
%bcond_without fuse
%bcond_without lz4
%bcond_without lzma
%bcond_without selinux
%bcond_without uuid
%bcond_without zlib

Name:           erofs-utils
Version:        1.8.1
Release:        %{anolis_release}%{?dist}

Summary:        Utilities for working with EROFS
License:        GPL-2.0-only AND GPL-2.0-or-later AND (GPL-2.0-only OR Apache-2.0) AND (GPL-2.0-or-later OR Apache-2.0) AND Unlicense
URL:            https://git.kernel.org/pub/scm/linux/kernel/git/xiang/erofs-utils.git

Source:         %{name}-%{version}.tar.gz

BuildRequires:  gcc
BuildRequires:  libtool
BuildRequires:  make

%{?with_libdeflate:BuildRequires:  pkgconfig(libdeflate)}
%if %{with fuse}
BuildRequires:  pkgconfig(fuse) >= 2.6
%endif
%if %{with lz4}
BuildRequires:  lz4-devel >= 1.9.3
%endif
%if %{with lzma}
BuildRequires:  xz-devel >= 5.4
%endif
%if %{with selinux}
BuildRequires:  pkgconfig(libselinux)
%endif
%if %{with uuid}
BuildRequires:  pkgconfig(uuid)
%endif
%{?with_zlib:BuildRequires:  pkgconfig(zlib)}

%description
EROFS stands for Enhanced Read-Only File System.  It aims to be a general
read-only file system solution for various use cases instead of just focusing
on saving storage space without considering runtime performance.

This package includes tools to create, check, and extract EROFS images.

%if %{with fuse}
%package -n erofs-fuse
Summary:        FUSE support for mounting EROFS images
Requires:       fuse

%description -n erofs-fuse
EROFS stands for Enhanced Read-Only File System.  It aims to be a general
read-only file system solution for various use cases instead of just focusing
on saving storage space without considering runtime performance.

This package includes erofsfuse to mount EROFS images.
%endif

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup
autoreconf -fi

%build
%configure \
    --%{?with_libdeflate:with}%{!?with_libdeflate:without}-libdeflate \
    %{?with_fuse:--enable-fuse} %{!?with_fuse:--disable-fuse} \
    %{?with_lz4:--enable-lz4} %{!?with_lz4:--disable-lz4} \
    %{?with_lzma:--enable-lzma} %{!?with_lzma:--disable-lzma} \
    %{?with_selinux:--with-selinux} %{!?with_selinux:--without-selinux} \
    %{?with_uuid:--with-uuid} %{!?with_uuid:--without-uuid} \
    --%{?with_zlib:with}%{!?with_zlib:without}-zlib
%make_build

%install
%make_install


%files
%{_bindir}/dump.erofs
%{_bindir}/fsck.erofs
%{_bindir}/mkfs.erofs
%{_mandir}/man1/dump.erofs.1*
%{_mandir}/man1/fsck.erofs.1*
%{_mandir}/man1/mkfs.erofs.1*
%license LICENSES/Apache-2.0 LICENSES/GPL-2.0

%if %{with fuse}
%files -n erofs-fuse
%{_bindir}/erofsfuse
%{_mandir}/man1/erofsfuse.1*
%license LICENSES/Apache-2.0 LICENSES/GPL-2.0
%endif

%files doc
%doc AUTHORS ChangeLog README docs/PERFORMANCE.md docs/compress-hints.example

%changelog
* Tue Aug 13 2024 Hongzhen Luo <hongzhen@linux.alibaba.com> - 1.8.1
- Update to the 1.8.1 release.

* Fri Oct 20 2023 Gao Xiang <hsiangkao@linux.alibaba.com> - 1.7.1-1
- Update to the 1.7.1 release.

* Tue Aug 08 2023 Gao Xiang <hsiangkao@linux.alibaba.com> - 1.6-1
- Initial package.
